==> django-froala-editor-0.9.0.tar.gz: django-froala-editor-0.9.0/froala_editor/static/froala_editor/js/langs/ar.js <==
/*!
 * froala_editor v1.1.9 (http://editor.froala.com)
 * Copyright 2014-2014 Froala
 */

/**
 * Arabic
 */

$.Editable.LANGS['ar'] = {
  translation: {
    "Bold": "\u063a\u0627\u0645\u0642",
    "Italic": "\u0645\u0627\u0626\u0644",
    "Underline": "\u062a\u0633\u0637\u064a\u0631",
    "Strikethrough": "\u064a\u062a\u0648\u0633\u0637 \u062e\u0637",
    "Font Size": "\u062d\u062c\u0645 \u0627\u0644\u062e\u0637",
    "Color": "\u0644\u0648\u0646",
    "Background Color": "\u0644\u0648\u0646 \u0627\u0644\u062e\u0644\u0641\u064a\u0629",
    "Text Color": "\u0644\u0648\u0646 \u0627\u0644\u0646\u0635",
    "Format Block": "\u0627\u0644\u062a\u0646\u0633\u064a\u0642\u0627\u062a",
    "Normal": "\u0637\u0628\u064a\u0639\u064a",
    "Paragraph": "\u0641\u0642\u0631\u0629",
    "Code": "\u0643\u0648\u062f",
    "Quote": "\u0639\u0644\u0627\u0645\u0627\u062a \u0627\u0644\u0627\u0642\u062a\u0628\u0627\u0633",
    "Heading 1": "\u0627\u0644\u0639\u0646\u0627\u0648\u064a\u0646 1",
    "Heading 2": "\u0627\u0644\u0639\u0646\u0627\u0648\u064a\u0646 2",
    "Heading 3": "\u0627\u0644\u0639\u0646\u0627\u0648\u064a\u0646 3",
    "Heading 4": "\u0627\u0644\u0639\u0646\u0627\u0648\u064a\u0646 4",
    "Heading 5": "\u0627\u0644\u0639\u0646\u0627\u0648\u064a\u0646 5",
    "Heading 6": "\u0627\u0644\u0639\u0646\u0627\u0648\u064a\u0646 6",
    "Alignment": "\u0645\u062d\u0627\u0630\u0627\u0629",
    "Align Left": "\u0645\u062d\u0627\u0630\u0627\u0629 \u0627\u0644\u0646\u0635 \u0644\u0644\u064a\u0633\u0627\u0631",
    "Align Center": "\u062a\u0648\u0633\u064a\u0637",
    "Align Right": "\u0645\u062d\u0627\u0630\u0627\u0629 \u0627\u0644\u0646\u0635 \u0644\u0644\u064a\u0645\u064a\u0646",
    "Justify": "\u0636\u0628\u0637",
    "Numbered List": "\u062a\u0631\u0642\u064a\u0645",
    "Bulleted List": "\u062a\u0639\u062f\u0627\u062f \u0646\u0642\u0637\u064a",
    "Indent Less": "\u0625\u0646\u0642\u0627\u0635 \u0627\u0644\u0645\u0633\u0627\u0641\u0629 \u0627\u0644\u0628\u0627\u062f\u0626\u0629",
    "Indent More": "\u0632\u064a\u0627\u062f\u0629 \u0627\u0644\u0645\u0633\u0627\u0641\u0629 \u0627\u0644\u0628\u0627\u062f\u0626\u0629",
    "Select All": "\u062a\u062d\u062f\u064a\u062f \u0627\u0644\u0643\u0644",
    "Insert Link": "\u0625\u062f\u0631\u0627\u062c \u0631\u0627\u0628\u0637",
    "Insert Image": "\u0625\u062f\u0631\u0627\u062c \u0635\u0648\u0631\u0629",
    "Insert Video": "\u0625\u062f\u0631\u0627\u062c \u0641\u064a\u062f\u064a\u0648",
    "Undo": "\u062a\u0631\u0627\u062c\u0639",
    "Redo": "\u0625\u0639\u0627\u062f\u0629",
    "Show HTML": "HTML \u0627\u0644\u0645\u0639\u0631\u0636",
    "Float Left": "\u064a\u0633\u0627\u0631",
    "Float None": "\u0628\u0644\u0627",
    "Float Right": "\u064a\u0645\u064a\u0646",
    "Replace Image": "\u0627\u0633\u062a\u0628\u062f\u0627\u0644 \u0635\u0648\u0631\u0629",
    "Remove Image": "\u0625\u0632\u0627\u0644\u0629 \u0635\u0648\u0631\u0629",
    "Title": "\u0627\u0644\u0639\u0646\u0648\u0627\u0646",
    "Insert image": "\u0625\u062f\u0631\u0627\u062c \u0635\u0648\u0631\u0629",
    "Drop image": "\u0625\u0633\u0642\u0627\u0637 \u0635\u0648\u0631\u0629",
    "or click": "\u0623\u0648 \u0627\u0646\u0642\u0631 \u0641\u0648\u0642",
    "Enter URL": "URL \u0625\u062f\u062e\u0627\u0644",
    "Please wait!": "!\u064a\u0631\u062c\u0649 \u0627\u0644\u0627\u0646\u062a\u0638\u0627\u0631",
    "Are you sure? Image will be deleted.": "\u0647\u0644 \u0623\u0646\u062a \u0645\u062a\u0623\u0643\u062f\u061f \u0633\u064a\u062a\u0645 \u062d\u0630\u0641 \u0627\u0644\u0635\u0648\u0631\u0629\u002e",
    "UNLINK": "\u062d\u0630\u0641 \u0627\u0644\u0631\u0627\u0628\u0637",
    "Open in new tab": "\u0641\u062a\u062d \u0641\u064a \u0639\u0644\u0627\u0645\u0629 \u062a\u0628\u0648\u064a\u0628 \u062c\u062f\u064a\u062f\u0629",
    "Type something": "\u0627\u0643\u062a\u0628 \u0634\u064a\u0626\u0627",
    "Cancel": "\u0625\u0644\u063a\u0627\u0621",
    "OK": "\u0645\u0648\u0627\u0641\u0642",
    "Manage images": "\u0625\u062f\u0627\u0631\u0629 \u0627\u0644\u0635\u0648\u0631",
    "Delete": "\u062d\u0630\u0641",
    "Font Family": "\u0639\u0627\u0626\u0644\u0629 \u0627\u0644\u062e\u0637",
    "Insert Horizontal Line": "\u0625\u062f\u0631\u0627\u062c \u062e\u0637 \u0623\u0641\u0642\u064a",
    "Table": "\u062c\u062f\u0648\u0644",
    "Insert table": "\u0625\u062f\u0631\u0627\u062c \u062c\u062f\u0648\u0644",
    "Cell": "\u062e\u0644\u064a\u0629",
    "Row": "\u0635\u0641",
    "Column": "\u0639\u0645\u0648\u062f",
    "Delete table": "\u062d\u0630\u0641 \u062c\u062f\u0648\u0644",
    "Insert cell before": "\u0625\u062f\u0631\u0627\u062c \u0627\u0644\u062e\u0644\u0627\u064a\u0627 \u0644\u0644\u064a\u0633\u0627\u0631",
    "Insert cell after": "\u0625\u062f\u0631\u0627\u062c \u0627\u0644\u062e\u0644\u0627\u064a\u0627 \u0644\u0644\u064a\u0645\u064a\u0646",
    "Delete cell": "\u062d\u0630\u0641 \u062e\u0644\u064a\u0629",
    "Merge cells": "\u062f\u0645\u062c \u062e\u0644\u0627\u064a\u0627",
    "Horizontal split": "\u0627\u0646\u0642\u0633\u0627\u0645 \u0623\u0641\u0642\u064a",
    "Vertical split": "\u0627\u0644\u0627\u0646\u0642\u0633\u0627\u0645 \u0627\u0644\u0639\u0645\u0648\u062f\u064a",
    "Insert row above": "\u0625\u062f\u0631\u0627\u062c \u0635\u0641 \u0644\u0644\u0623\u0639\u0644\u0649",
    "Insert row below": "\u0625\u062f\u0631\u0627\u062c \u0635\u0641 \u0644\u0644\u0623\u0633\u0641\u0644",
    "Delete row": "\u062d\u0630\u0641 \u0635\u0641",
    "Insert column before": "\u0625\u062f\u0631\u0627\u062c \u0639\u0645\u0648\u062f \u0644\u0644\u064a\u0633\u0627\u0631",
    "Insert column after": "\u0625\u062f\u0631\u0627\u062c \u0639\u0645\u0648\u062f \u0644\u0644\u064a\u0645\u064a\u0646",
    "Delete column": "\u062d\u0630\u0641 \u0639\u0645\u0648\u062f"
  },
 direction : "rtl"
};

==> django-froala-editor-1.2.3.tar.gz: django-froala-editor-1.2.3/froala_editor/static/froala_editor/js/langs/ar.js <==
/*!
 * froala_editor v1.2.3 (http://editor.froala.com)
 * Copyright 2014-2014 Froala
 */

/**
 * Arabic
 */

$.Editable.LANGS['ar'] = {
  translation: {
    "Bold": "\u063a\u0627\u0645\u0642",
    "Italic": "\u0645\u0627\u0626\u0644",
    "Underline": "\u062a\u0633\u0637\u064a\u0631",
    "Strikethrough": "\u064a\u062a\u0648\u0633\u0637 \u062e\u0637",
    "Font Size": "\u062d\u062c\u0645 \u0627\u0644\u062e\u0637",
    "Color": "\u0644\u0648\u0646",
    "Background": "\u0627\u0644\u062e\u0644\u0641\u064a\u0629",
    "Text": "\u0627\u0644\u0646\u0635",
    "Format Block": "\u0627\u0644\u062a\u0646\u0633\u064a\u0642\u0627\u062a",
    "Normal": "\u0637\u0628\u064a\u0639\u064a",
    "Paragraph": "\u0641\u0642\u0631\u0629",
    "Code": "\u0643\u0648\u062f",
    "Quote": "\u0639\u0644\u0627\u0645\u0627\u062a \u0627\u0644\u0627\u0642\u062a\u0628\u0627\u0633",
    "Heading 1": "\u0627\u0644\u0639\u0646\u0627\u0648\u064a\u0646 1",
    "Heading 2": "\u0627\u0644\u0639\u0646\u0627\u0648\u064a\u0646 2",
    "Heading 3": "\u0627\u0644\u0639\u0646\u0627\u0648\u064a\u0646 3",
    "Heading 4": "\u0627\u0644\u0639\u0646\u0627\u0648\u064a\u0646 4",
    "Heading 5": "\u0627\u0644\u0639\u0646\u0627\u0648\u064a\u0646 5",
    "Heading 6": "\u0627\u0644\u0639\u0646\u0627\u0648\u064a\u0646 6",
    "Block Style": "\u0623\u0633\u0644\u0648\u0628 \u0643\u062a\u0644\u0629",
    "Alignment": "\u0645\u062d\u0627\u0630\u0627\u0629",
    "Align Left": "\u0645\u062d\u0627\u0630\u0627\u0629 \u0627\u0644\u0646\u0635 \u0644\u0644\u064a\u0633\u0627\u0631",
    "Align Center": "\u062a\u0648\u0633\u064a\u0637",
    "Align Right": "\u0645\u062d\u0627\u0630\u0627\u0629 \u0627\u0644\u0646\u0635 \u0644\u0644\u064a\u0645\u064a\u0646",
    "Justify": "\u0636\u0628\u0637",
    "Numbered List": "\u062a\u0631\u0642\u064a\u0645",
    "Bulleted List": "\u062a\u0639\u062f\u0627\u062f \u0646\u0642\u0637\u064a",
    "Indent Less": "\u0625\u0646\u0642\u0627\u0635 \u0627\u0644\u0645\u0633\u0627\u0641\u0629 \u0627\u0644\u0628\u0627\u062f\u0626\u0629",
    "Indent More": "\u0632\u064a\u0627\u062f\u0629 \u0627\u0644\u0645\u0633\u0627\u0641\u0629 \u0627\u0644\u0628\u0627\u062f\u0626\u0629",
    "Select All": "\u062a\u062d\u062f\u064a\u062f \u0627\u0644\u0643\u0644",
    "Insert Link": "\u0625\u062f\u0631\u0627\u062c \u0631\u0627\u0628\u0637",
    "Insert Image": "\u0625\u062f\u0631\u0627\u062c \u0635\u0648\u0631\u0629",
    "Insert Video": "\u0625\u062f\u0631\u0627\u062c \u0641\u064a\u062f\u064a\u0648",
    "Undo": "\u062a\u0631\u0627\u062c\u0639",
    "Redo": "\u0625\u0639\u0627\u062f\u0629",
    "Show HTML": "HTML \u0627\u0644\u0645\u0639\u0631\u0636",
    "Float Left": "\u064a\u0633\u0627\u0631",
    "Float None": "\u0628\u0644\u0627",
    "Float Right": "\u064a\u0645\u064a\u0646",
    "Replace Image": "\u0627\u0633\u062a\u0628\u062f\u0627\u0644 \u0635\u0648\u0631\u0629",
    "Remove Image": "\u0625\u0632\u0627\u0644\u0629 \u0635\u0648\u0631\u0629",
    "Title": "\u0627\u0644\u0639\u0646\u0648\u0627\u0646",
    "Drop image": "\u0625\u0633\u0642\u0627\u0637 \u0635\u0648\u0631\u0629",
    "or click": "\u0623\u0648 \u0627\u0646\u0642\u0631 \u0641\u0648\u0642",
    "or": "\u0623\u0648",
    "Enter URL": "URL \u0625\u062f\u062e\u0627\u0644",
    "Please wait!": "!\u064a\u0631\u062c\u0649 \u0627\u0644\u0627\u0646\u062a\u0638\u0627\u0631",
    "Are you sure? Image will be deleted.": "\u0647\u0644 \u0623\u0646\u062a \u0645\u062a\u0623\u0643\u062f\u061f \u0633\u064a\u062a\u0645 \u062d\u0630\u0641 \u0627\u0644\u0635\u0648\u0631\u0629\u002e",
    "UNLINK": "\u062d\u0630\u0641 \u0627\u0644\u0631\u0627\u0628\u0637",
    "Open in new tab": "\u0641\u062a\u062d \u0641\u064a \u0639\u0644\u0627\u0645\u0629 \u062a\u0628\u0648\u064a\u0628 \u062c\u062f\u064a\u062f\u0629",
    "Type something": "\u0627\u0643\u062a\u0628 \u0634\u064a\u0626\u0627",
    "Cancel": "\u0625\u0644\u063a\u0627\u0621",
    "OK": "\u0645\u0648\u0627\u0641\u0642",
    "Manage images": "\u0625\u062f\u0627\u0631\u0629 \u0627\u0644\u0635\u0648\u0631",
    "Delete": "\u062d\u0630\u0641",
    "Font Family": "\u0639\u0627\u0626\u0644\u0629 \u0627\u0644\u062e\u0637",
    "Insert Horizontal Line": "\u0625\u062f\u0631\u0627\u062c \u062e\u0637 \u0623\u0641\u0642\u064a",
    "Table": "\u062c\u062f\u0648\u0644",
    "Insert table": "\u0625\u062f\u0631\u0627\u062c \u062c\u062f\u0648\u0644",
    "Cell": "\u062e\u0644\u064a\u0629",
    "Row": "\u0635\u0641",
    "Column": "\u0639\u0645\u0648\u062f",
    "Delete table": "\u062d\u0630\u0641 \u062c\u062f\u0648\u0644",
    "Insert cell before": "\u0625\u062f\u0631\u0627\u062c \u0627\u0644\u062e\u0644\u0627\u064a\u0627 \u0644\u0644\u064a\u0633\u0627\u0631",
    "Insert cell after": "\u0625\u062f\u0631\u0627\u062c \u0627\u0644\u062e\u0644\u0627\u064a\u0627 \u0644\u0644\u064a\u0645\u064a\u0646",
    "Delete cell": "\u062d\u0630\u0641 \u062e\u0644\u064a\u0629",
    "Merge cells": "\u062f\u0645\u062c \u062e\u0644\u0627\u064a\u0627",
    "Horizontal split": "\u0627\u0646\u0642\u0633\u0627\u0645 \u0623\u0641\u0642\u064a",
    "Vertical split": "\u0627\u0644\u0627\u0646\u0642\u0633\u0627\u0645 \u0627\u0644\u0639\u0645\u0648\u062f\u064a",
    "Insert row above": "\u0625\u062f\u0631\u0627\u062c \u0635\u0641 \u0644\u0644\u0623\u0639\u0644\u0649",
    "Insert row below": "\u0625\u062f\u0631\u0627\u062c \u0635\u0641 \u0644\u0644\u0623\u0633\u0641\u0644",
    "Delete row": "\u062d\u0630\u0641 \u0635\u0641",
    "Insert column before": "\u0625\u062f\u0631\u0627\u062c \u0639\u0645\u0648\u062f \u0644\u0644\u064a\u0633\u0627\u0631",
    "Insert column after": "\u0625\u062f\u0631\u0627\u062c \u0639\u0645\u0648\u062f \u0644\u0644\u064a\u0645\u064a\u0646",
    "Delete column": "\u062d\u0630\u0641 \u0639\u0645\u0648\u062f"
  },
 direction : "rtl"
};
